/*-------------------------------------------------------------------------+
| Copyright 2015 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.labelprovider;

import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.fortiss.tooling.base.annotation.valueprovider.IAnnotationValueProvider;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;
import org.fortiss.tooling.base.ui.annotation.view.IAnnotationViewPart;
import org.fortiss.tooling.base.ui.annotation.view.generic.GenericAnnotationView;

/**
 * Factory to build {@link LabelProviderBase}-based {@link ColumnLabelProvider}s for the
 * {@link GenericAnnotationView}.
 * 
 * @author barner
 */
public class LabelProviderFactory {

	/**
	 * Creates an {@link ColumnLabelProvider} for the given {@link IAnnotatedSpecification}.
	 * 
	 * @param valueProvider
	 *            Annotation's {@link IAnnotationValueProvider}
	 * @param viewPart
	 *            {@link IAnnotationViewPart} in which the annotation will be displayed.
	 * @param columnViewer
	 *            {@link ColumnViewer} used to display annotation
	 * @param editingSupport
	 *            {@link EditingSupport} that has been provided for the annotation.
	 * @param clazz
	 *            Annotation type
	 * @param specification
	 *            Annotation instance
	 * @return {@link ColumnLabelProvider} for the given {@link IAnnotatedSpecification}.
	 */
	public static <T extends IAnnotatedSpecification> ColumnLabelProvider createLabelProvider(
			IAnnotationValueProvider<T> valueProvider, IAnnotationViewPart viewPart,
			ColumnViewer columnViewer, EditingSupport editingSupport,
			Class<? extends IAnnotatedSpecification> clazz, T specification) throws Exception {

		if(valueProvider.getAnnotationValue(specification) instanceof Boolean) {
			return new CheckBoxLabelProvider(clazz, viewPart, editingSupport);
		}
		return new AnnotationLabelProvider(clazz, viewPart, editingSupport);
	}
}
