/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.utils;

import static org.junit.Assert.assertNotNull;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;

/**
 * Utility methods for handling JFace {@link Action}s.
 * 
 * @author hoelzl
 */
public class ActionUtils {

	/**
	 * Setup an enabled action with name, tool tip, and icons.
	 * 
	 * @param action
	 *            the action to set up
	 * @param name
	 *            the action name
	 * @param toolTip
	 *            the action tool tip
	 * @param icon
	 *            the action's enabled icon
	 * @param disabledIcon
	 *            the action's disabled icon
	 */
	public static void setUpAction(Action action, String name, String toolTip, ImageDescriptor icon,
			ImageDescriptor disabledIcon) {
		action.setText(name);
		action.setToolTipText(toolTip);
		action.setEnabled(true);

		assertNotNull(icon);
		assertNotNull(disabledIcon);

		action.setImageDescriptor(icon);
		action.setDisabledImageDescriptor(disabledIcon);
	}
}
