/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui.util;

import static org.lwjgl.BufferUtils.createFloatBuffer;

import java.nio.FloatBuffer;

import org.fortiss.tooling.graphicsGL.model.Color3D;
import org.fortiss.tooling.graphicsGL.model.Vector3D;

/**
 * Utility methods for handling {@link FloatBuffer} more easily.
 * 
 * @author hoelzl
 */
public class FloatBufferUtils {
	/** Creates a float buffer for the given value array. */
	public static FloatBuffer toFloatBuffer(float[] f) {
		FloatBuffer buf = createFloatBuffer(f.length);
		buf.put(f);
		buf.flip();
		return buf;
	}

	/** Creates a float buffer for the given value array. */
	public static FloatBuffer toFloatBuffer(float x, float y, float z) {
		FloatBuffer buf = createFloatBuffer(3);
		buf.put(x).put(y).put(z).flip();
		return buf;
	}

	/** Creates a float buffer for the given value array. */
	public static FloatBuffer toFloatBuffer(float x, float y, float z, float w) {
		FloatBuffer buf = createFloatBuffer(4);
		buf.put(x).put(y).put(z).put(w).flip();
		return buf;
	}

	/** Creates a 3-element float buffer for the given {@link Vector3D}. */
	public static FloatBuffer toFloatBuffer(Vector3D vec) {
		if(vec == null) {
			return toFloatBuffer(0, 0, 0);
		}
		return toFloatBuffer(vec.getX(), vec.getY(), vec.getZ());
	}

	/**
	 * Creates a 4-element float buffer for the given {@link Vector3D} and the additional element.
	 */
	public static FloatBuffer toFloatBuffer(Vector3D vec, float w) {
		if(vec == null) {
			return toFloatBuffer(0, 0, 0, 0);
		}
		return toFloatBuffer(vec.getX(), vec.getY(), vec.getZ(), w);
	}

	/** Creates a 3-element float buffer for the given {@link Vector3D}. */
	public static FloatBuffer toFloatBuffer(Color3D vec) {
		if(vec == null) {
			return toFloatBuffer(0, 0, 0);
		}
		return toFloatBuffer(vec.getRed(), vec.getGreen(), vec.getBlue());
	}

	/**
	 * Creates a 4-element float buffer for the given {@link Vector3D} and the additional element.
	 */
	public static FloatBuffer toFloatBuffer(Color3D vec, float w) {
		if(vec == null) {
			return toFloatBuffer(0, 0, 0, 0);
		}
		return toFloatBuffer(vec.getRed(), vec.getGreen(), vec.getBlue(), w);
	}
}
