/*******************************************************************************
 * Copyright (c) 2019 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef;

import static java.util.Collections.emptyList;
import static java.util.Collections.unmodifiableList;

import java.util.List;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundle;

/**
 * A {@link DiagramViewerSelection} wraps {@link IMVCBundle}s, which are currently selected. Each
 * selection consists of a primary selection and zero or more secondary selections.
 */
public final class DiagramViewerSelection {
	/** The primary selection. */
	private final IMVCBundle primarySelection;
	/** The list of secondary selections. */
	private final List<IMVCBundle> secondarySelections;

	/** Constructor. */
	public DiagramViewerSelection(IMVCBundle primary) {
		this(primary, emptyList());
	}

	/** Constructor. */
	public DiagramViewerSelection(IMVCBundle primary, List<IMVCBundle> secondary) {
		this.primarySelection = primary;
		this.secondarySelections = unmodifiableList(secondary);
	}

	/** Returns the primary selection. */
	public IMVCBundle getPrimarySelection() {
		return primarySelection;
	}

	/** Returns the secondary selections. */
	public List<IMVCBundle> getSecondarySelections() {
		return secondarySelections;
	}

	/** Returns whether nothing is selected. */
	public boolean isEmpty() {
		return primarySelection == null && secondarySelections.isEmpty();
	}

	/** Returns whether multiple elements are currently selected. */
	public boolean isMultiSelection() {
		return primarySelection != null && !secondarySelections.isEmpty();
	}

	/** Returns whether the given bundle is selected or not. */
	public boolean isSelected(IMVCBundle bundle) {
		return primarySelection == bundle || secondarySelections.contains(bundle);
	}
}
