/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.change.Change;

import javafx.scene.Node;
import javafx.scene.input.MouseEvent;

/**
 * Interface for controllers, which handle click gestures provided by the visuals. Each operation
 * may result in {@link Change} to the underlying model.
 */
public interface IClickController {
	/** Handles a single-click at the given mouse location. */
	Change singleClick(MouseEvent event, Node node, DiagramCoordinate lastMouseLocation);

	/** Handles a double-click at the given mouse location. */
	Change doubleClick(MouseEvent event, Node node, DiagramCoordinate lastMouseLocation);

	/**
	 * Handles a single click at the given mouse location when the secondary mouse button is used.
	 */
	Change secondaryClick(MouseEvent event, Node node, DiagramCoordinate lastMouseLocation);
}
