/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewer;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IDiagramAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IDiagramMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.ILinkMVCBundle;

/**
 * Interface for factories which create controllers for model elements in a {@link DiagramViewer}.
 */
public interface IControllerFactory {
	/** Returns the controller instance for the given content model. */
	IController createContentController(IContentMVCBundle model);

	/** Returns the controller instance for the given diagram anchorage model. */
	IController createDiagramAnchorageController(IDiagramAnchorageMVCBundle modelBundle);

	/**
	 * Returns the controller instance for the given content anchorage model. Sub-classes may assume
	 * that {@code model.getAttachedTo()} points to the parent {@link IContentMVCBundle}.
	 */
	IController createContentAnchorageController(IContentAnchorageMVCBundle modelBundle);

	/**
	 * Returns the controller instance for the given link model. Sub-classes may assume that
	 * {@code modelBundle.getAttachedTo()} points to the parent {@link IDiagramMVCBundle}.
	 */
	IController createLinkController(ILinkMVCBundle modelBundle);

	/**
	 * Returns the controller instance for the given diagram bundle. This method is called only once
	 * when the diagram is initialized.
	 */
	IController createDiagramController(IDiagramMVCBundle diagramBundle);
}
