/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.base;

import static org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.EDragGesture.MOVE;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.EDragGesture;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.IController;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.IDragController;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentMVCBundle;

import javafx.scene.Cursor;
import javafx.scene.Node;

/**
 * Default {@link IController} implementation for moving anchorage visuals attached to a parent
 * visual. This controller delegates to the parent controller and tries to acquire an anchorage move
 * controller from it, because in most cases the shape of the parent determines the possible
 * locations of the anchorages.
 */
public class DelegatingContentAnchorageController extends ControllerBase {
	/** Constructor. */
	public DelegatingContentAnchorageController(IContentAnchorageMVCBundle mvcb) {
		super(mvcb);
	}

	/** Returns the {@link IContentAnchorageMVCBundle}. */
	private IContentAnchorageMVCBundle getContentAnchorageBundle() {
		// Wild cast works: see constructor
		return (IContentAnchorageMVCBundle)getMVCBundle();
	}

	/** {@inheritDoc} */
	@Override
	public IDragController getDragController(EDragGesture gesture, Node node,
			DiagramCoordinate diagramLocation) {
		if(gesture == MOVE && allowMove()) {
			IContentAnchorageMVCBundle contentAnchorageBundle = getContentAnchorageBundle();
			IContentMVCBundle parent = contentAnchorageBundle.getAttachedTo();
			if(parent != null && parent.getController() instanceof AnchorageContentControllerBase) {
				AnchorageContentControllerBase parentController =
						(AnchorageContentControllerBase)parent.getController();
				return parentController.getAnchorageMoveController(contentAnchorageBundle);
			}
			return null;
		}
		return super.getDragController(gesture, node, diagramLocation);
	}

	/** {@inheritDoc} */
	@Override
	public Cursor getCurrentCursor(Node node, DiagramCoordinate diagramLocation) {
		EDragGesture edg = getVisual().getDragGesture(node, diagramLocation);
		if(edg == EDragGesture.MOVE) {
			return allowMove() ? Cursor.MOVE : Cursor.DEFAULT;
		}
		return super.getCurrentCursor(node, diagramLocation);
	}

	/** Returns whether the model element can be moved. */
	protected boolean allowMove() {
		return true;
	}
}
