/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.model;

import java.util.ArrayList;
import java.util.List;

/** Base class for model change listeners. */
public abstract class ModelChangeProviderBase implements IModelChangeProvider {
	/** The registered listeners. */
	private final List<IModelChangeListener> listeners = new ArrayList<>();

	/** {@inheritDoc} */
	@Override
	public void addListener(IModelChangeListener l) {
		if(!listeners.contains(l)) {
			listeners.add(l);
			connectToModel();
		}
	}

	/** Called when the first listener is added. */
	protected void connectToModel() {
		// does nothing
	}

	/** {@inheritDoc} */
	@Override
	public void removeListener(IModelChangeListener l) {
		listeners.remove(l);
		if(listeners.isEmpty()) {
			disconnectFromModel();
		}
	}

	/** Called when the last listener is removed. */
	protected void disconnectFromModel() {
		// does nothing
	}

	/** {@inheritDoc} */
	@Override
	public void fireUpdateComplete() {
		// use a copy to avoid concurrent modification exception
		ArrayList<IModelChangeListener> iterationSafeCopy = new ArrayList<>(listeners);
		for(IModelChangeListener l : iterationSafeCopy) {
			l.changed(this);
		}
	}
}
