/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewer;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.FeedbackChange;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.IController;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.IVisual;

/** Interface for bundles composed of a model, a view, and a controller. */
public interface IMVCBundle {
	/** Returns the model. */
	Object getModel();

	/** Returns the visual. */
	IVisual getVisual();

	/** Sets the visual. */
	void setVisual(IVisual v);

	/** Returns the controller. */
	IController getController();

	/** Sets the controller. */
	void setController(IController c);

	/** Returns the diagram viewer. */
	DiagramViewer getViewer();

	/** Returns the feedback change (temporary location or size changes during user gestures). */
	FeedbackChange getFeedbackChange();

	/** Sets the feedback change (temporary location or size changes during user gestures). */
	void setFeedbackChange(FeedbackChange fc);

	/** Attaches listeners to the visual and the underlying model. */
	void attach();

	/** Detaches listeners from the visual and from the underlying model. */
	void detach();

	/** Adds the given tag to this bundle. */
	void addTag(MVCBundleTag tag);

	/** Returns the tag of this bundle matching the given tags identifier. */
	MVCBundleTag getTag(MVCBundleTag tag);

	/** Returns whether this bundle is tagged with the given tag (using equals()). */
	boolean hasTag(MVCBundleTag tag);

	/** Removes the tag from this bundle. */
	void removeTag(MVCBundleTag tag);

	/** Removes the bundle from any other bundle it is related to. */
	void remove();
}
