/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;

import javafx.scene.Node;

/**
 * {@link IVisual} for content nodes moving freely on the diagram background.
 * Content nodes can normally be resized and have anchorage visuals.
 */
public interface IContentVisual extends IVisual {
	/**
	 * Returns the location on the border of this content visual for the given
	 * {@link IContentAnchorageVisual}.
	 */
	DiagramCoordinate getAnchorageLocation(IContentAnchorageVisual visual);

	/** Returns whether the given node is the expand/collapse widget. */
	boolean isExpandCollapseWidget(Node node);

	/**
	 * Returns whether anchorage visuals attached to this visual should be updated when this content
	 * visual is hovered over by the mouse pointer. The default is {@code false}.
	 * 
	 * @see IContentAnchorageVisual#updateSiblingAnchorageVisualsOnHover()
	 */
	boolean updateAttachedAnchorageVisualsOnHover();
}
