/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.base;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramLayers;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramLayers.ILayer;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewerFeatures;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.FeedbackChange;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.IContentAnchorageVisual;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.IContentVisual;

import javafx.geometry.Dimension2D;
import javafx.geometry.Point2D;
import javafx.geometry.Rectangle2D;
import javafx.scene.paint.Color;
import javafx.scene.paint.Paint;
import javafx.scene.shape.Shape;

/** Base implementation of {@link IContentAnchorageVisual}. */
public abstract class ContentAnchorageVisualBase extends VisualBase
		implements IContentAnchorageVisual {
	/** Constructor. */
	public ContentAnchorageVisualBase(IContentAnchorageMVCBundle mvcb, Shape visual, Shape hit) {
		super(mvcb, visual, hit);
	}

	/** {@inheritDoc} */
	@Override
	public IContentAnchorageMVCBundle getMVCBundle() {
		// wild cast works: see constructor
		return (IContentAnchorageMVCBundle)super.getMVCBundle();
	}

	/** {@inheritDoc} */
	@Override
	protected ILayer getLayerForVisualShape(DiagramLayers layers) {
		return layers.getAnchorageLayer();
	}

	/** {@inheritDoc} */
	@Override
	protected ILayer getLayerForHitShape(DiagramLayers layers) {
		return layers.getAnchorageInteractionLayer();
	}

	/** Returns the location of the visual in its parent coordinate system. */
	protected Point2D getLocationOnParent() {
		IContentVisual cv = getMVCBundle().getAttachedTo().getVisual();
		return cv.getAnchorageLocation(this);
	}

	/** {@inheritDoc} */
	@Override
	public Rectangle2D getCurrentBounds() {
		Rectangle2D parentBounds = getMVCBundle().getAttachedTo().getVisual().getCurrentBounds();
		Point2D modelLocationOnParent = getLocationOnParent();
		Dimension2D size = getDimensions();
		FeedbackChange chg = getFeedbackChange();
		double x = parentBounds.getMinX() + modelLocationOnParent.getX() + chg.getDeltaX();
		double y = parentBounds.getMinY() + modelLocationOnParent.getY() + chg.getDeltaY();
		return new Rectangle2D(x, y, size.getWidth(), size.getHeight());
	}

	/** {@inheritDoc} */
	@Override
	public Dimension2D getDimensions() {
		DiagramViewerFeatures features = getViewer().getFeatures();
		return new Dimension2D(features.getHorizontalSpacing(), features.getVerticalSpacing());
	}

	/** Returns the color to be used when the port is highlighted as incoming port. */
	protected Paint getHighlightIncomingLinkColor() {
		return Color.GREENYELLOW;
	}

	/** Returns the color to be used when the port is highlighted as outgoing port. */
	protected Paint getHighlightOutgoingLinkColor() {
		return Color.TOMATO;
	}

	/** Returns the color of the border to be used when the port is highlighted as incoming port. */
	protected Paint getHighlightIncomingLinkBorderColor() {
		return Color.GREENYELLOW.darker();
	}

	/** Returns the color of the border to be used when the port is highlighted as outgoing port. */
	protected Paint getHighlightOutgoingLinkBorderColor() {
		return Color.TOMATO.darker();
	}

	/** {@inheritDoc} */
	@Override
	public boolean updateSiblingAnchorageVisualsOnHover() {
		return false;
	}
}
