/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.style;

import javafx.scene.canvas.GraphicsContext;
import javafx.scene.paint.Color;

/**
 * Represents a style to be used for lines and provides a corresponding
 * {@link #drawLine(GraphicsContext, double, double, double, double) drawLine} method.
 */
public final class LineStyle extends ColorStyleBase {
	/** Solid, black line with width of one point. */
	public static final LineStyle SOLID_BLACK_1PT =
			new LineStyle(Color.BLACK, 1, StrokeStyle.SOLID);
	/** The style of the stroke of the line. */
	private final StrokeStyle strokeStyle;
	/** The width of the line. */
	private final double width;

	/** Constructor */
	public LineStyle(Color rgbColor, double width, StrokeStyle strokeStyle) {
		super(rgbColor);
		this.width = width;
		this.strokeStyle = strokeStyle;
	}

	/** Constructor */
	public LineStyle(Color rgbColor) {
		this(rgbColor, 1, StrokeStyle.SOLID);
	}

	/** Applies the line style to the given graphics context. */
	public void applyStyle(GraphicsContext gc) {
		gc.setStroke(getColor());
		gc.setLineWidth(width);
		strokeStyle.applyStyle(gc);
	}

	/** Draws a line */
	public void drawLine(GraphicsContext gc, double x1, double y1, double x2, double y2) {
		gc.save();
		applyStyle(gc);
		gc.moveTo(x1, y1);
		gc.lineTo(x2, y2);
		gc.restore();
	}
}
