/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.databinding.validate;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;

/**
 * Validator that prevents the use of names already used.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: F910046BE6E08D4720F337DF61AA24A5
 */
public class DuplicateNameValidator implements IValidator {

	/** Names which are already used. */
	private Set<String> usedNames;

	/** Constructor. */
	public DuplicateNameValidator(Collection<String> usedNames) {
		this.usedNames = new HashSet<String>(usedNames);
	}

	/** {@inheritDoc} */
	public IStatus validate(Object value) {
		if (usedNames.contains(value)) {
			return ValidationStatus.error("Name already used!");
		}
		return ValidationStatus.ok();
	}
}